@@ -121,17 +121,17 @@ void CFatPart::printfInformations()
   getStdInfos(szText, sizeof(szText), false);
 
   SNPRINTF(szFullText, i18n("%s" // standard infos
-			    "Sector Size...................%u\n"
-			    "Sectors per cluster...........%u\n"
-			    "Reserved Sectors count........%u\n"
-			    "Root directory sectors........%lu\n"
-			    "FAT tables count..............%u\n"
-			    "Total Sectors Count...........%lu\n"
-			    "Sectors per FAT...............%lu\n"
-			    "Clusters count:...............%lu\n"
-			    "Used clusters.................%lu\n"
-			    "Free clusters.................%lu\n"
-			    "Damaged clusters..............%lu\n"),
+			    "Sector Size:..................%u\n"
+			    "Sectors per cluster:..........%u\n"
+			    "Reserved Sectors count:.......%u\n"
+			    "Root directory sectors:.......%u\n"
+			    "FAT tables count:.............%u\n"
+			    "Total Sectors Count:..........%u\n"
+			    "Sectors per FAT:..............%u\n"
+			    "Clusters count:...............%u\n"
+			    "Used clusters:................%u\n"
+			    "Free clusters:................%u\n"
+			    "Damaged clusters:.............%u\n"),
 	   szText, m_info.wBytesPerSector, m_info.cSectorsPerCluster,
 	   m_info.wReservedSectorsCount, m_info.dwRootDirSectors,
 	   m_info.cNumberOfFATs,m_info.dwTotalSectorsCount,
@@ -340,7 +340,7 @@ void CFatPart::readSuperBlock()
   
   if (m_info.cSectorsPerCluster == 0)
     {
-      g_interface->msgBoxError(i18n("m_cSectorsPerCluster can't be null. Check the partition to save is a FAT one.") );
+      g_interface->msgBoxError(i18n("The sectors per cluster number can't be null. Check the partition to verify it's a FAT one.") );
       THROW(ERR_WRONG_FS);
     }
   
@@ -375,8 +375,8 @@ void CFatPart::readSuperBlock()
 
   if ((nRes == -1) && (m_info.dwFileSystem == FS_FAT32))
     {
-      showDebug(1, "Can't read FSInfo sector\n");
-      g_interface->msgBoxError(i18n("Can't read FSInfo sector"));
+      showDebug(1, "Can't read the filesystem information sector\n");
+      g_interface->msgBoxError(i18n("Can't read the filesystem information sector"));
       setSuperBlockInfos(false, false, 0, 0);
     }
 
